0.26.8 UPD 28 Ağu Windows, Linux

İndir T-Rex Miner

T-rex madenci yazılımı — Eksiksiz Kılavuz

-a, --algo                     Kullanılacak hash algoritmasını belirtir.
                                   autolykos2
                                   blake3
                                   etchash
                                   ethash
                                   firopow
                                   kawpow
                                   mtp
                                   mtp-tcr
                                   multi
                                   octopus
                                   progpow
                                   progpow-veil
                                   progpow-veriblock
                                   progpowz
                                   tensority
        --coin                     Coin adını ayarlar.
                                   Dev fee oturumundan geri dönerken DAG'ın yeniden oluşturulmasını önlemeye yardımcı olur.
                                   Örnek: Ethereum Classic için "etc", Ethereum Classic + Zilliqa madenciliği için "etc+zil".
        --extra-dag-epoch          Belirtilen epoch için GPU'da ek DAG ayırır. Zilliqa (ZIL) gibi coinlerin dual
                                   madenciliğinde faydalı olabilir. (örn: --extra-dag-epoch 0)
                                   Virgülle ayrılmış değer listesi kullanılarak her GPU için ayrı ayrı ayarlanabilir
                                   (ek DAG ayırmaması gereken GPU'lar için -1 olarak ayarlayın).
        --nonce-start              [Ethash, ProgPOW] Çözüm araması için başlangıç nonce değeri.
        --nonce-range-size         [Ethash, ProgPOW] Nonce araması için nonce aralığı boyutu. Aralık tüm cihazlar arasında bölünür.
    -d, --devices                  Kullanılacak CUDA cihazlarının virgülle ayrılmış listesi.
                                   Cihaz ID'leri 0'dan başlayarak sayılır.
        --ab-indexing              Afterburner indekslemesi (varsayılanla aynı, ancak 1'den başlar).
        --devices-info             Sistemdeki kullanılabilir CUDA uyumlu cihazların listesini yazdırır.
    -i, --intensity                GPU yoğunluğu 8-25 (varsayılan: auto).
                                   GPU iş yükü boyutunu, yani madenci yazılımının "tek seferde" kaç nonce
                                   işlediğini kontrol eder: N = 2 ^ intensity
        --low-load                 Düşük yük modu (varsayılan: 0). 1 - etkin, 0 - devre dışı.
                                   Mümkünse GPU'lardaki yükü azaltır. Modu GPU listesinin bir kısmı için etkinleştirmek üzere
                                   virgülle ayrılmış bir dize olarak ayarlanabilir (örn: --low-load 0,0,1,0)
        --dual-algo                Dual madencilik modunda kullanılacak ikinci algoritma.
        --dual-algo-mode           Dual madencilik modunda GPU davranışını kontrol eder (varsayılan: a12).
                                   Biçim: <algo>:<tuning coefficient>
                                   "<algo>" şunlardan biri olabilir: "a1" (birinci algoritma), "a2" (ikinci algoritma), "a12" (ikisi birden - dual madencilik)
                                   "<tuning coefficient>" isteğe bağlıdır ve şunlardan biri olabilir:
                                         "rXX" ("dual ratio" katsayısı XX olarak ayarlanır) veya
                                         "rXX:lrYY" ("dual ratio" katsayısı XX, "LHR dual ratio" katsayısı YY olarak ayarlanır) veya
                                         "hXX" (birincil algoritmanın hashrate yüzdesi XX).
                                   Daha fazla ayrıntı için dual madencilik kılavuzuna bakın.
        --profit-per-mh            Dual madencilik modunda algoritmaların 1MH hashrate başına tahmini kârlılığı.
                                   algo1/algo2 oranının ince ayarı için kullanılır, madenci yazılımı kazancı en üst düzeye çıkarmaya çalışır.
                                   Biçim: <profit_algo1>:<profit_algo2>.
                                   Örnek: --profit-per-mh 0.0516:0.0012
        --lhr-tune                 [Ethash, Autolykos2] Madenci yazılımının LHR kartlarda ulaşmaya çalıştığı tam hızın yüzdesini
                                   gösteren LHR ayar değeri (varsayılan: -1). Aralık: 10 ile 95 arası.
                                   -1 - auto
                                    0 - devre dışı (LHR olmayan kartlar için kullanın)
                                   74 - düşük güç modundaki çoğu LHR kart için önerilen başlangıç değeri (bkz. --lhr-low-power)
                                   78 - çoğu LHR kart için önerilen başlangıç değeri
                                   Her GPU için ayrı ayrı ayarlanabilir, örn.
                                   "lhr-tune": "0,0,77.5,0" - bu, üçüncü GPU için LHR ayar değerini 77.5 olarak ayarlar.
        --lhr-autotune-mode        [Ethash, Autolykos2] LHR otomatik ayar modu (varsayılan: down). Geçerli değerler:
                                   off  - otomatik ayar devre dışıdır. LHR ayar değeri madencilik sırasında sabittir ve
                                          LHR kilidi ne sıklıkla algılanırsa algılansın değişmez
                                   down - madenci yazılımı LHR kilidi algılarsa LHR ayar değeri düşer
                                   full - "down" ile aynı, ancak ek olarak madenci yazılımı mevcut LHR ayar seviyesinde
                                          kararlıysa LHR ayar değerini artırmaya çalışır
        --lhr-autotune-step-size   LHR otomatik ayar adım boyutu (varsayılan: 0.1).
                                   LHR otomatik ayarlayıcısının LHR ayar değerini ne kadar değiştirdiğini belirtir.
        --lhr-autotune-interval    Dakika cinsinden LHR otomatik ayar zaman aralığı (varsayılan: 5:120).
                                   Biçim: <interval_up>:<interval_down>.
                                   "<interval_up>", madenci yazılımı LHR ayar değerini artırmayı denemeden önce GPU'nun
                                   LHR kilidine takılmadan madencilik yapması gereken dakika cinsinden süredir.
                                   GPU LHR'ye takıldıysa ve önceki LHR kilidi "<interval_down>" dakikadan daha önce
                                   algılandıysa LHR ayar değeri düşmez.
        --lhr-low-power            [Ethash] Biraz daha düşük hashrate pahasına LHR modunda güç tüketimini azaltır (varsayılan: 0).
                                   1 - etkin, 0 - devre dışı. Modu GPU'ların bir kısmı için etkinleştirmek üzere
                                   virgülle ayrılmış bir dize olarak ayarlanabilir (örn: --lhr-low-power 0,0,1,0)
        --kernel                   [Ethash] CUDA kernel'ını seçer (varsayılan: 0). Aralık: 0 ile 5 arası.
                                   Otomatik ayarı etkinleştirmek için 0 yapın: madenci yazılımı her kernel'ı test edip en hızlısını seçer.
                                   Farklı kartlara farklı değerler uygulamak için virgülle ayrılmış liste olarak ayarlanabilir.
                                   (örn: --kernel 2,1,1,3)
                                   Bu parametrenin desteği ileride diğer algoritmaları da kapsayacak şekilde genişletilebilir.
        --gpu-init-mode            DAG'ın sıralı başlatılmasını etkinleştirir (varsayılan: 0).
                                   0 - tüm GPU'lar paralel olarak başlatılır
                                   1 - tamamen sıralı başlatma, bir seferde bir GPU
                                   2 - bir seferde iki GPU
                                   vb.
        --dag-build-mode           [Ethash, ProgPOW, Octopus] DAG'ın nasıl oluşturulacağını kontrol eder (varsayılan: 0).
                                   0 - auto (madenci yazılımı GPU modeline göre en uygun modu seçer)
                                   1 - varsayılan (çoğu ekran kartı için uygundur)
                                   2 - geçersiz share'leri önlemek için 30xx kartlarda önerilir
                                   Farklı kartlara farklı değerler uygulamak için virgülle ayrılmış liste olarak ayarlanabilir.
                                   (örn: --dag-build-mode 1,1,2,1)
        --dataset-mode             [Autolykos2] Dataset modu. (varsayılan: 2). Geçerli değerler:
                                   0 - auto (varsayılan olarak 2)
                                   1 - single (her ERGO bloğunda GPU, dataset'i oluşturana kadar hash hesaplamayı durdurur)
                                   2 - double (madenci yazılımı bir sonraki ERGO bloğu için dataset'i blok gelmeden önce oluşturur;
                                       bu, raporlanan hashrate'te küçük bir kayba yol açar, ancak bir sonraki blok geldiğinde
                                       dataset oluşturmaya 1-4 saniye kaybetmeden hemen hash hesaplamaya başlar).
                                       GPU iki bellek tamponu tutmak zorunda olduğundan bu modda bellek gereksinimi iki katına çıkar.
                                       GPU'da iki dataset için yeterli bellek yoksa madenci yazılımı
                                       tek tampon moduna geri döner.
        --keep-gpu-busy            Havuz bağlantısı kopsa bile madenciliğe devam eder.
                                   İnternet bağlantısı kesildiğinde meydana gelen başlatma/durdurma döngüsü sırasında
                                   GPU çöküyorsa faydalıdır.

    -o, --url                      Madencilik havuzunun şu biçimdeki URL'si: <scheme>://<host>:<port>
                                   Desteklenen şemalar: stratum+tcp
                                                      stratum+ssl
                                                      stratum+http
                                                      stratum2+tcp
                                                      stratum2+ssl
                                   stratum2 genellikle Nicehash, MiningPoolHub ve benzeri madencilik havuzları tarafından kullanılır
                                   Örnek: stratum+tcp://eu1.ethermine.org:4444
                                            stratum+ssl://zcoin.mintpond.com:3005
                                            stratum2+tcp://daggerhashimoto.hk.nicehash.com:3353
        --url2                     Dual madencilik modunda ikinci algoritma için kullanılan ikinci madencilik havuzunun URL'si.
    -u, --user                     Madencilik sunucusu için kullanıcı adı.
        --user2                    Dual madencilik modunda ikinci algoritma için kullanılan madencilik sunucusunun kullanıcı adı.
    -p, --pass                     Madencilik sunucusu için parola.
        --pass2                    Dual madencilik modunda ikinci algoritma için kullanılan madencilik sunucusunun parolası.
    -w, --worker                   Worker adı.
        --worker2                  Dual madencilik modunda ikinci algoritma için kullanılan madencilik sunucusundaki worker adı.
        --proxy                    SOCKS5 proxy sunucusu üzerinden bağlantı için IP:port.
                                   Alan adları da proxy üzerinden çözümlenir.
        --dns-https-server         DNS-over-HTTPS ile çalışan DNS sunucusu için IP:port.
    -r, --retries                  Bir ağ çağrısı başarısız olursa kaç kez yeniden deneneceği.
    -R, --retry-pause              Yeniden denemeler arasındaki saniye cinsinden bekleme süresi.
    -T, --timeout                  Saniye cinsinden ağ zaman aşımı (varsayılan: 300)
        --time-limit               Saniye cinsinden madenci yazılımını kapatma aralığı. (varsayılan: 0 - devre dışı)
        --temperature-color        GPU istatistikleri için çekirdek sıcaklığı rengini ayarlar. Örnek: 55,65 - bu,
                                   55'in üzerindeki sıcaklıkların sarı, 65'in üzerindekilerin kırmızı renkte olacağı anlamına gelir. (varsayılan: 67,77)
        --temperature-color-mem    GPU istatistikleri için bellek sıcaklığı rengini ayarlar. (varsayılan: 80,100)
        --temperature-limit        GPU'nun kapatılacağı çekirdek sıcaklığı. (varsayılan: 0 - devre dışı)
        --temperature-start        Devre dışı bırakılan kartın yeniden etkinleştirileceği GPU çekirdek sıcaklığı. (varsayılan: 0 - devre dışı)
        --api-bind-http            HTTP üzerinden madenci yazılımı API'si için IP:port (varsayılan: 127.0.0.1:4067). Devre dışı bırakmak için 0 yapın.
                                   Dışarıdan erişim için IP'yi 0.0.0.0 yapın; bu durumda "--api-read-only" ayarlanması da
                                   önerilir.
        --api-https                API çağrıları için https protokolünü etkinleştirir.
        --api-key                  API çağrıları için önceden oluşturulmuş yetkilendirme anahtarı. Oluşturmak için "--api-generate-key" kullanın.
                                   Değiştirme/güncelleme API çağrılarına izin vermek için zorunludur.
        --api-read-only            API çağrıları için yalnızca okuma işlemlerine izin verir.
                                   "--api-key" ayarlanmamışsa varsayılan olarak etkindir.
        --api-generate-key         Kullanıcı tanımlı paroladan API anahtarı oluşturur. Çıktı anahtarı "--api-key" değeri olarak kullanılır.
                                   api-key'i doğrudan yapılandırma dosyanıza yazmak için bu seçeneği "-c" ile birlikte kullanın.
        --api-webserver-cert       API web sunucusu sertifika dosyasının tam yolu.
        --api-webserver-pkey       API web sunucusu özel anahtar dosyasının tam yolu.
    -N, --hashrate-avr             Ortalama hashrate'i hesaplamak için kullanılan saniye cinsinden kayan pencere uzunluğu (varsayılan: 60, maks: 86400).
        --sharerate-avr            Sharerate'i hesaplamak için kullanılan saniye cinsinden kayan pencere uzunluğu (varsayılan: 600).
        --gpu-report-interval      GPU istatistik raporu sıklığı. Minimum 5 sn. (varsayılan: 30 sn)
        --gpu-report-interval-s    Share cinsinden GPU istatistik raporu sıklığı. Varsayılan olarak 0 (devre dışı).
    -q, --quiet                    Sessiz mod. Hiç GPU istatistiği gösterilmez.
        --hide-date                Konsolda tarihi göstermez.
        --send-stales              Stale share'leri atmaz.
        --validate-shares          Share'leri havuza göndermeden önce doğrular. Ayrıca share zorluk bilgisini de etkinleştirir.
        --no-color                 Konsol için renkli çıktıyı devre dışı bırakır.
        --no-hashrate-report       Havuza hashrate raporunu devre dışı bırakır.
        --no-new-block-info        Konsolda yeni blok bilgisini yazdırmaz.
        --no-nvml                  NVML GPU istatistiklerini devre dışı bırakır.
        --no-strict-ssl            SSL bağlantıları için sertifika doğrulamasını devre dışı bırakır.
        --no-sni                   SSL bağlantıları için SNI başlığının ayarlanmasını devre dışı bırakır.
        --no-watchdog              Yerleşik watchdog'u devre dışı bırakır.
        --watchdog-exit-mode       Madenci yazılımı "M" dakika içinde "N" kez yeniden başlatılırsa watchdog'un
                                   yapması gereken "A" eylemini belirtir.
                                   Biçim: N:M:A. Geçerli değerler:
                                                  N: herhangi bir pozitif tam sayı,
                                                  M: herhangi bir pozitif tam sayı,
                                                  A: r(sistemi yeniden başlatma), s(sistemi kapatma), e(madenci yazılımından çıkış)
                                   "r" ve "s" eylemleri, madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
                                   Örnekler:
                                   20:10:s - madenci yazılımı herhangi bir 10 dakikalık aralıkta 20 kez yeniden başlatılırsa
                                             watchdog sistemi kapatır
                                   5:7:r   - madenci yazılımı herhangi bir 7 dakikalık aralıkta 5 kez yeniden başlatılırsa
                                             watchdog sistemi yeniden başlatır
    -B, --benchmark                Benchmark modu.
        --benchmark-epoch          Benchmark sırasında kullanılan epoch numarası (varsayılan: 0).
                                   Yalnızca ProgPOW ailesi dışındaki DAG tabanlı algoritmalar için geçerlidir.
        --benchmark-block          Benchmark sırasında kullanılan blok numarası (varsayılan: 0).
                                   Yalnızca ProgPOW algoritma ailesi için geçerlidir.
    -P, --protocol-dump            Kullanıcı protokolü günlüğü.
    -c, --config                   JSON biçimli bir yapılandırma dosyası yükler.
    -l, --log-path                 Günlük dosyasının tam yolu.
        --cpu-priority             İşlem önceliğini ayarlar (varsayılan: 2) 0 boşta, 2 normal, 5 en yüksek.
        --autoupdate               Madenci yazılımının daha yeni bir sürümü çıktığında otomatik güncelleme yapar.
        --back-to-main-pool-sec    Yedek havuzla çalışılıyorsa madenci yazılımını ana havuza geri dönmeye zorlar.
                                   Parametre saniye cinsinden ayarlanır. (varsayılan: 600)
        --exit-on-cuda-error       CUDA hatasında madenci yazılımını hemen çıkmaya zorlar.
        --exit-on-connection-lost  Bağlantı koptuğunda madenci yazılımını hemen çıkmaya zorlar.
        --exit-on-high-power       Yüksek güç tüketiminde madenci yazılımını hemen çıkmaya zorlar.
                                   (örn: --exit-on-high-power 600 - toplam güç tüketimi 600W'ı aşarsa çıkış)
        --reconnect-on-fail-shares Art arda N başarısız share'de madenci yazılımını havuza hemen yeniden bağlanmaya zorlar (varsayılan: 10).
        --fork-at                  Madenci yazılımını önceden tanımlanmış bir koşulda algoritma değiştirmeye zorlar (yalnızca yerleşik watchdog etkinken çalışır)
                                   Epoch koşulu: <algo_name>=epoch:<epoch_number> (örn: --fork-at etchash=epoch:390).
                                   Blok koşulu: <algo_name>=block:<block_number> (örn: --fork-at x16rv2=block:6526421).
                                   Zaman koşulu:  <algo_name>=time:<YYYY-MM-DDTHH:MM:SS>. Zaman UTC+0 olarak ayarlanmalıdır.
                                   (örn: --fork-at firopow=time:2021-10-26T06:00:00).
                                   Ana havuz portunu değiştirmek için portu algoritmadan hemen sonra yazmalısınız: <algo_name>:<port_number>
                                   (örn: --fork-at x16rv2:4081=time:2019-10-01T16:00:00).

  --------------------- İsteğe bağlı betik çalıştırma -------------------
    -- (betikler t-rex çalıştırılabilir dosyasıyla aynı dizinde bulunmalıdır) --
    -------------------------------------------------------------------------

        --script-start             Madenci yazılımı başladıktan hemen sonra kullanıcı betiğini çalıştırır (örn: --script-start script_filename)
        --script-exit              Madenci yazılımından çıkmadan hemen önce kullanıcı betiğini çalıştırır.
        --script-epoch-change      Epoch değiştiğinde kullanıcı betiğini çalıştırır.
        --script-crash             Madenci yazılımı çökerse kullanıcı betiğini çalıştırır.
        --script-low-hash          Hash düşük olursa kullanıcı betiğini çalıştırır. Hash eşiği MegaHash/saniye cinsinden ayarlanır.
                                   Örnek: --script-low-hash script_to_activate:50
                                            (toplam hashrate 50MH/s'ye düştüğünde "script_to_activate" betiğini çalıştırır)

  -------------------- GPU ince ayarı (Windows ve Linux) -----------------

        --pl                       GPU güç limitini ayarlar (Windows - yüzde olarak, Linux - watt olarak)
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
        --lock-cclock              İstenen sabit GPU çekirdek frekansını MHz cinsinden belirtir. (varsayılan: 0 - devre dışı).
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
                                   Örnek: --lock-cclock 1000 (bu işlevi destekleyen tüm kartlara 1000Mhz frekans uygular)
                                            --lock-cclock 1000,1300,0 (GPU #0'a 1000Mhz, GPU #1'e 1300MHz uygular, GPU #2'yi yok sayar)
        --mt                       Bellek ince ayar (memory tweak) modu (varsayılan: 0 - devre dışı). Aralık: 0 ile 6 arası. Genel öneri,
                                   1 ile başlamak ve yalnızca GPU kararlıysa artırmaktır.
                                   Etkisi ETHlargementPill'inkine benzer.
                                   Yalnızca GDDR5 veya GDDR5X belleğe sahip Pascal GPU'larda desteklenir.
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
                                   Farklı kartlara farklı değerler uygulamak için virgülle ayrılmış liste olarak ayarlanabilir.
                                   Örnek: --mt 4 (bu işlevi destekleyen tüm kartlara 4 numaralı ince ayar modunu uygular)
                                            --mt 3,3,3,0 (sonuncusu hariç tüm kartlara 3 numaralı ince ayar modunu uygular)

  -------------------- GPU ince ayarı (yalnızca Windows) -------------------

                                   Farklı kartlara farklı değerler uygulamak için tüm seçenekler virgülle ayrılmış
                                   liste olarak ayarlanabilir. (tüm seçenekler için varsayılan değer: 0 - kullanılmaz)
        --fan                      GPU fan hızını yüzde olarak veya hedef sıcaklığı (auto-fan) ayarlar.
                                   Geçerli biçimler:
                                      --fan N           (N fan hızıdır)
                                      --fan t:N         (N hedef çekirdek sıcaklığıdır)
                                      --fan t:N[F1-F2]  (yukarıdakiyle aynı, ancak fan hızı [F1%, F2%] aralığıyla sınırlandırılır)
                                      --fan tm:N        (N hedef bellek sıcaklığıdır)
                                      --fan tm:N[F1-F2] (yukarıdakiyle aynı, ancak fan hızı [F1%, F2%] aralığıyla sınırlandırılır)
                                   Örnek: --fan 45,t:67,tm:95,t:69[45-100],tm:90[50-95]
                                   bunun anlamı şudur:
                                      GPU #0: fan hızını %45'e ayarla
                                      GPU #1: GPU çekirdek sıcaklığını 67C'de tut
                                      GPU #2: GPU bellek sıcaklığını 95C'de tut
                                      GPU #3: GPU çekirdek sıcaklığını 69C'de tut,
                                              fan hızı [45%, 100%] aralığıyla sınırlı
                                      GPU #4: GPU bellek sıcaklığını 90C'de tut,
                                              fan hızı [50%, 95%] aralığıyla sınırlı
                                   Not: auto-fan modunda fan hızları varsayılan olarak [0%, 100%] aralığıyla sınırlıdır.
        --cclock                   GPU çekirdek frekansı ofsetini MHz cinsinden ayarlar.
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
                                   Çıkışta ve DAG yeniden oluşturulurken 0 olarak ayarlanır.
        --mclock                   GPU bellek frekansı ofsetini MHz cinsinden ayarlar.
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
                                   Çıkışta ve DAG yeniden oluşturulurken 0 olarak ayarlanır.
        --cv                       GPU çekirdek voltajını yüzde olarak ayarlar. [0, 100] aralığında olmalıdır.
                                   Yalnızca ne yaptığınızı biliyorsanız kullanın!
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
        --lock-cv                  İstenen GPU çekirdek voltajını mV cinsinden belirtir. (varsayılan: 0 - devre dışı).
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.
        --pstate                   GPU P-state'ini ayarlar. Geçerli değerler: p0.
                                   Madenci yazılımının yönetici yetkileriyle çalıştırılmasını gerektirir.

 -------------------------------------------------------------------------

        --version                  Sürüm bilgisini görüntüler ve çıkar.
    -h, --help                     Bu yardım metnini görüntüler ve çıkar.

İndir T-Rex Miner

0.26.8